@@ -76,6 +76,7 @@ class App:
         self.window.show_all()
         # make some changes after main window is shown.
         self.lrc.after_init()
+        self.artists.after_init()
         self.player.after_init()
         self.search.after_init()
         self.shortcut = Shortcut(self.player)
@@ -165,9 +166,11 @@ class App:
 
     def load_styles(self):
         font_size = str(int(self.conf['lrc-text-size']))
-        px = ''
-        if Gtk.MINOR_VERSION > 6:
+        if Config.GTK_LE_36:
+            px = ''
+        else:
             px = 'px'
+
         css = '\n'.join([
             'GtkScrolledWindow.lrc_window {',
                 'transition-property: background-image;',
